# Mercurial for Windows

Welcome to Mercurial for Windows!

Mercurial is a command-line application. You must run it from the Windows command prompt (or if you're hard core, a MinGW shell).

Note: the standard MinGW msys startup script uses rxvt which has problems setting up standard input and output. Running bash directly works correctly.

For documentation, please visit the Mercurial web site. You can also download a free book, Mercurial: The Definitive Guide.

By default, Mercurial installs to `C:\Program Files\Mercurial`. The Mercurial command is called `hg.exe`.

# Testing Mercurial after you've installed it

The easiest way to check that Mercurial is installed properly is to just type the following at the command prompt:

    hg

This command should print a useful help message. If it does, other Mercurial commands should work fine for you.

# Configuration notes

#### Default editor

The default editor for commit messages is 'notepad'. You can set the `EDITOR` (or `HGEDITOR`) environment variable to specify your preference or set it in `mercurial.ini`:

    [ui]
    editor = whatever

#### Configuring a Merge program

It should be emphasized that Mercurial by itself doesn't attempt to do a Merge at the file level, neither does it make any attempt to Resolve the conflicts.

By default, Mercurial will use the merge program defined by the `HGMERGE` environment variable, or uses the one defined in the `mercurial.ini` file. (see MergeProgram on the Mercurial Wiki for more information)

# Reporting problems

Before you report any problems, please consult the Mercurial web site and see if your question is already in our list of Frequently Answered Questions (the "FAQ").

If you cannot find an answer to your question, please feel free to send mail to the Mercurial mailing list, at mercurial@mercurial-scm.org. Remember, the more useful information you include in your report, the easier it will be for us to help you!

If you are IRC-savvy, that's usually the fastest way to get help. Go to `#mercurial` on `irc.freenode.net`.

# Author and copyright information

Mercurial was written by Matt Mackall, and is maintained by Matt and a team of volunteers.

The Windows installer was written by Bryan O'Sullivan.

Mercurial is Copyright 2005-2017 Matt Mackall and others. See the `Contributors.txt` file for a list of contributors.

Mercurial is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License version 2 or any later version.

Mercurial is distributed in the hope that it will be useful, but without any warranty; without even the implied warranty of merchantability or fitness for a particular purpose. See the GNU General Public License for more details.